/*
 *     AUTHOR: Trevor Woerner
 * START DATE: 02 January 2001 - 10:36:30 PM
 *   MODIFIED: 07 January 2001 - 10:08:31 PM
 *   FILENAME:
 *    PURPOSE:
 *
 * $Revision$
 * Copyright (C) 2001  Trevor Woerner
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * To receive a copy of the GNU General Public License write to
 * the Free Software Foundation, 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <DPS/psops.h>
#include <DPS/dpsXclient.h>
#include <X11/Intrinsic.h>
#include "wraps.h"

Display *d_ptr;

int main( void )
{
    int screen;
    DPSContext ctxt,txtCtxt;
    Window win;
    int blackPixel,whitePixel;
    int debug = False;
    GC gc;
    XSetWindowAttributes attrs;
    float width,height;
    Bool done = False;
    XEvent thisEvent;
    int winWidth=200,winHeight=200;

    if( (d_ptr = XOpenDisplay(0)) == 0 ) {
        fprintf( stderr, "can't open display\n" );
        return 1;
    }

    screen = DefaultScreen( d_ptr );
    blackPixel = BlackPixel( d_ptr, screen );
    whitePixel = WhitePixel( d_ptr, screen );
    attrs.background_pixel = whitePixel;
    attrs.border_pixel = blackPixel;
    attrs.bit_gravity = SouthWestGravity;
    attrs.event_mask = StructureNotifyMask | ButtonReleaseMask | ExposureMask;

    win = XCreateWindow( d_ptr, DefaultRootWindow(d_ptr), 50, 50, winWidth, winHeight,
            1, CopyFromParent, InputOutput, CopyFromParent,
            CWBackPixel | CWBorderPixel | CWBitGravity | CWEventMask, &attrs );
    XMapWindow( d_ptr, win );

    gc = XCreateGC( d_ptr, RootWindow(d_ptr,screen), 0, 0 );

    ctxt = XDPSCreateSimpleContext( d_ptr, win, gc, 0, 200, DPSDefaultTextBackstop,
            DPSDefaultErrorProc, 0 );
    if( ctxt == NULL ) {
        fprintf( stderr, "can't create ctxt\n" );
        return 1;
    }
   
    DPSSetContext( ctxt );
    (void) XDPSSetEventDelivery( d_ptr, dps_event_pass_through );

    while( !done ) {
        XNextEvent( d_ptr, &thisEvent );
        if( thisEvent.xany.window == win ) {
            switch( thisEvent.type ) {
                case Expose:
                    PSitransform( (float)winWidth, (float)winHeight, &width, &height );
                    PSWDrawBox( 0.77, 0.58, 0.02, width/4.0, -(height/4.0), width/2.0, -(height/2.0) );
                    break;

                case ButtonRelease:
                    done = True;
                    break;

                case ConfigureNotify:
                    winWidth = thisEvent.xconfigure.width;
                    winHeight = thisEvent.xconfigure.height;
                    break;
            }
        }
    }
    
    DPSDestroySpace( DPSSpaceFromContext(ctxt) );

    XFreeGC( d_ptr, gc );
    XFree( d_ptr );

    return 0;
}
